#  %Z%%M%   %I%   %W%  %G%  %U%
#
# COMPONENT_NAME:
#
# FUNCTION: rmadpm.pm
#
# Tivoli SecureWay Risk Manager
# (C) Copyright Tivoli Systems, Inc., an IBM Company, 2000.
# All Rights Reserved
# Licensed Materials - Property of IBM/Tivoli Systems
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Revision History:
#
#-----------------------------------------------------------------------
# Declarations.
#-----------------------------------------------------------------------

package rmadpm;

use Carp;

require 5.005;
require Exporter;
require DynaLoader;

@ISA = qw(Exporter DynaLoader);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use rmadpm ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
%EXPORT_TAGS = ( 'all' => [ qw() ] );

@EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
@EXPORT = qw( );

$VERSION = '0.01';

sub AUTOLOAD {
    # This AUTOLOAD is used to 'autoload' constants from the constant()
    # XS function.  If a constant is not found then control is passed
    # to the AUTOLOAD in AutoLoader.

    my $constname;
    our $AUTOLOAD;
    ($constname = $AUTOLOAD) =~ s/.*:://;
    croak "& not defined" if $constname eq 'constant';
    my $val = constant($constname, @_ ? $_[0] : 0);
    if ($! != 0) {
	if ($! =~ /Invalid/ || $!{EINVAL}) {
	    $AutoLoader::AUTOLOAD = $AUTOLOAD;
	    goto &AutoLoader::AUTOLOAD;
	}
	else {
	    croak "Your vendor has not defined rmadpm macro $constname";
	}
    }
    {
	no strict 'refs';
	# Fixed between 5.005_53 and 5.005_61
	if ($] >= 5.00561) {
	    *$AUTOLOAD = sub () { $val };
	}
	else {
	    *$AUTOLOAD = sub { $val };
	}
    }
    goto &$AUTOLOAD;
}

bootstrap rmadpm $VERSION;

# Preloaded methods go here.

# Autoload methods go after =cut, and are processed by the autosplit program.

1;
__END__
# Below is stub documentation for your module. You better edit it!

=head1 NAME

rmadpm - Perl extension for the Risk Manager Common Adapter Toolkit

=head1 SYNOPSIS

  use rmadpm;

=head1 DESCRIPTION

This Perl module provides the glue code between Perl and the Risk Manager Common Adapter Toolkit (librmad.so or libramd.dll).


=head2 EXPORT

int rmad_info(int, char*)

    Query information about the Risk Manager CAT facilities

    Returns 0 if successful. If an error is encountered, the value -1 is 
    returned. If more than one error can cause failure, errno will also be set.

int rmad_initialize(void)

    Initializes the adapter daemon, enabling the adapter to send events to 
    the event server.  

       Process flow for this API is as follows:

         Starts the Common Adapter Daemon (CAD)  (if not already started)

         Opens pipes for communication with the CAD

         Formats and writes an init message to the pipe

         Waits for an acknowledgement from the CAD for a predefined period

         Increment use count (number of Risk Manager adapter using shared 
			      library)

         Returns 0 upon receipt of an ack,  -1 on time out

    Returns 0 if successful. If an error is encountered, the value -1 is 
    returned. If more than one error can cause failure, errno will also be set.

int rmad_send_message(char*, int)

    Sends an event to the Risk Manager common adapter daemon.

    The event data supplied to this API, by an adapter, can be supplied in 
    either attribute/value pair format or a string of values to be formatted
    into a class and attribute/value pairs based upon a CDS-format file 
    defined for the adapter. 

    Format is selected by the second parameter.

    Returns 0 if successful. If an error is encountered, the value -1 is 
    returned. If more than one error can cause failure, errno will also be set.

void rmad_terminate(int)

    Kill the common adapter process

=head1 AUTHOR

ROE  11:07:36 06/23/00

=head1 SEE ALSO

perl(1).

=cut

